/**
 * Lazy
 * ```ts
 * import lazy from '../lib/directive/lazy.ts'
 * new Vue({
 *   directives: {lazy}
 * })
 * ```
 * * enabled (default: true)
 * * onIntersect (default: null)
 * * once (default: true)
 *
 * ```html
 * <UiImage v-lazy="{enabled:true, onIntersect: el => el.src = computedSrc, once: true}"/>
 * <UiImage v-lazy="{enabled:true, onIntersect: (el, vnode) => ..., once: false}"/>
 * ```
 */
import { Directive, VNode } from "vue";
export type OnIntersect = (el: Element, vnode: VNode) => void;
declare global {
    interface Element {
        onIntersect?: () => void;
        onIntersectOnce?: boolean;
    }
}
declare const _default: Directive;
export default _default;
