import dayjs from "dayjs"

/**
 * `targetTime`이 될 때가지 시간을 count down 하며,
 * 1초 단위로 `callback` 함수를 호출한다.
 * `targetTime`이 되면 `diff=0`으로 callback 을 호출하고, count down 이 종료된다.
 */
export class CountDownTimer {

  private targetTime?: dayjs.Dayjs
  private interval?: ReturnType<typeof setInterval>

  constructor(private callback: (diff: number) => void) {
  }

  isRunning(): boolean {
    return !!this.interval
  }

  start(targetTime: dayjs.Dayjs): void {
    this.targetTime = targetTime
    this.countDown()
    if (!this.isRunning()) {
      this.interval = setInterval(() => {
        this.countDown()
      }, 1000)
    }
  }

  stop(): void {
    if (this.interval) {
      clearInterval(this.interval)
      this.interval = undefined
    }
  }

  countDown(): void {
    const diff = Math.max(0, this.targetTime?.diff(dayjs()) || 0)
    this.callback(diff)
    if (diff === 0) {
      this.stop()
    }
  }
}